@@ -2,7 +2,7 @@
  * DFArc main frame
 
  * Copyright (C) 2005, 2006  Dan Walma
- * Copyright (C) 2008, 2010, 2014  Sylvain Beucler
+ * Copyright (C) 2008, 2010, 2014, 2017  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -220,10 +220,9 @@ void DFArcFrame::OnAbout(wxCommandEvent& aCommandEvent)
     "DFArc version %s\n"
     "Copyright (C) 2004  Andrew Reading (merlin)\n"
     "Copyright (C) 2005, 2006  Dan Walma (redink1)\n"
-    "Copyright (C) 2008-2014  Sylvain Beucler (Beuc)\n"
-    "Build Date: %s\n"
+    "Copyright (C) 2008-%04d  Sylvain Beucler (Beuc)\n"
     "Powered by bzip2 (bzip.org) and wxWidgets (wxwidgets.org)"),
-				  version.c_str(), __TDATE__);
+				  version.c_str(), 2018);
   wxMessageBox(wxs, _("About DFArc v3"), wxOK | wxICON_INFORMATION, this);
 }
 
@@ -406,10 +405,12 @@ void DFArcFrame::Install(wxCommandEvent& aCommandEvent)
 
 void DFArcFrame::onPackage(wxCommandEvent &Event)
 {
-  DMod cur_dmod = mAvailableDModsList.at(mSelectedDModIndex);
-  Package* lPackage = new Package(cur_dmod);
-  lPackage->ShowModal();
-  lPackage->Destroy();
+  if (mSelectedDModIndex != wxNOT_FOUND) {
+    DMod cur_dmod = mAvailableDModsList.at(mSelectedDModIndex);
+    Package* lPackage = new Package(cur_dmod);
+    lPackage->ShowModal();
+    lPackage->Destroy();
+  }
 }
 
 void DFArcFrame::OnSetPlayOption(wxCommandEvent &Event)
